
Group {
  surface = Region[101] ;
  source  = Region[102] ;
  body    = Region[1001] ;
  node    = Region[1002] ;
  Det1    = Region[91];
  Det2    = Region[92];
  Dets    = Region[{ Det1, Det2}];

  Vol_Phi        = Region[{ body,node}] ;
  Sur_Phi        = Region[{ surface, source}] ;
  Sur_Source_PhiIn = Region[{ source}] ;
  Sur_Source_PhiOut = Region[{ source}] ;
  Tot_Phi        = Region[{ Vol_Phi, Sur_Phi}];
}


eps   = 1.e-8;
c     = 1.e+8;
alpha = 1.0; // Coefficient determining the flux at the boundary:
// 0.0 denotes reflection (zero exiting flux) at the boundary
// 1.0 denotes "perfectly matched layer": no reflected flux at the boundary
// > 1.0 implies decreasing photon density at the boundary.  
// This is approaching an "essential" boundary condition: phi == 0 on the 
// boundary.  This should be handled as a true boundary condition on the 
// function space.  Note also that alpha >> 1.0 tends to make the problem 
// unstable near the source.


Function {

  mu_a[] = 0.400 * 1000;	// mm^-1 converted to m^-1
  mu_s[] = 0.5   * 1000;	// mm^-1 converted to m^-1

  sigmax[ body] = 0;		// no cross-coupling in rest of body
  sigmax[ node] = 0.1;		// cross-coupling on node

  t0 = 0;
  t1 = 3.0e-10;
  dt = 3.0e-12;
  //dt = 30.0e-12;
  tpulse = 3 * dt;
  saveSteps = 5.0;
  dtTheta = 0.6;		// 0.5: Crank-Nicholson, > 0.5: more implicit

  kappa[ ] =  1 / (3.0*( mu_a[ ] + mu_s[ ])) ;

  TimeFct[] = ($Time < tpulse) ? 1 : 0 ;

  Flux[] = 1e5 * TimeFct[] ;
  FluxOut[] = 0;

  SaveFct[] = !($TimeStep % saveSteps) ; 

}

Include "DiffusionInOut.pro"

PostOperation {
        
    { Name map ; NameOfPostProcessing both ;
      Operation {
        Print[ PhiIn , OnElementsOf Vol_Phi , File "mapPhiIn.pos" ];
        Print[ PhiOut, OnElementsOf Vol_Phi , File "mapPhiOut.pos"];
      }
    }    
    
//     /* pour 3D ep = 0.0061 ;*/
//     /* pour 2D ep = 0 ; */
//     ep = 0;
//     alt = 0.0115 ;

//     { Name cut ; NameOfPostProcessing Phi ;
//       Operation {
//         Print[ Phi, OnCut {{0,0,ep/2}{1,0,ep/2}{0,1,ep/2}} , File "cut1.pos"];
//         Print[ Phi, OnCut {{0,alt,0}{0,alt,1}{1,alt,0}} , File "cut2.pos"];
//       }
//     }    

//     { Name point ; NameOfPostProcessing Phi ;
//       Operation {
//         Print[ Phi, OnPoint {0.044,0.012001,0} , File "Tcont" , Format TimeTable];
//       }
//     }
  

//     { Name point3d ; NameOfPostProcessing Phi ;
//       Operation {
//         Print[ Phi, OnPoint {0.0425,0.011001,ep/2} , File "Tcont" , Format TimeTable];
//       }
//     }
    { Name Plot_t;   NameOfPostProcessing both;
      Operation { 
	//Print [ Phi , OnElementsOf Dets, File "Dets.plt", Format GmshParsed] ;
	Print [ PhiIn , OnPoint {0.01,0,0}, File "PhiIn.plt" , Format GmshParsed] ;
	Print [ PhiOut, OnPoint {0.01,0,0}, File "PhiOut.plt", Format GmshParsed] ;
      }
    }

}
