
Jacobian {
  { Name JVol ;
    Case { 
      { Region All ; Jacobian Vol ; }
    }
  }
  { Name JSur ;
    Case {
      { Region All ; Jacobian Sur ; }
    }
  }
}

Integration {
  { Name I1 ;
    Case { 
      { Type Gauss ;
        Case { 
          { GeoElement Point       ; NumberOfPoints  1 ; }
          { GeoElement Line        ; NumberOfPoints  3 ; }
          { GeoElement Triangle    ; NumberOfPoints  4 ; }
          { GeoElement Quadrangle  ; NumberOfPoints  4 ; }
          { GeoElement Tetrahedron ; NumberOfPoints  4 ; }
          { GeoElement Hexahedron  ; NumberOfPoints  6 ; }
          { GeoElement Prism       ; NumberOfPoints  6 ; } 
        }
      }
    }
  }
}

FunctionSpace {
  { Name phiIn; Type Form0; 
    BasisFunction {
      { Name si; NameOfCoef vi; Function BF_Node; Support Tot_Phi; 
        Entity NodesOf[All]; }
    }
    Constraint {
      { NameOfCoef vi; EntityType NodesOf ; NameOfConstraint bcIn; }
    }
  }

  { Name phiOut; Type Form0; 
    BasisFunction {
      { Name so; NameOfCoef vo; Function BF_Node; Support Tot_Phi; 
        Entity NodesOf[All]; }
    }
    Constraint {
      { NameOfCoef vo; EntityType NodesOf ; NameOfConstraint bcOut; }
    }
  }

}

Function{
  DefineFunction[Flux, kappa, mu_a, mu_s,sigmax];
}
//Group{
//  DefineGroup[SurConv_Phi];
//}

Formulation {
  // First problem: diffusion in
  { Name DIn ; Type FemEquation; 
    Quantity { 
      { Name PhiIn;  Type Local; NameOfSpace phiIn; }
    }
    Equation {
      // Diffusion term: kappa is combination of mu_s and mu_a
      Galerkin { [ kappa[] * Dof{d PhiIn} , {d PhiIn} ]; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
      // Attenuation (body loss) term
      Galerkin { [ mu_a[] * Dof{PhiIn} , {PhiIn} ] ; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
      // Time dependence
      Galerkin { Dt [ 1/c * Dof{PhiIn} , {PhiIn} ]; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }

      // end of volume terms, beginning of surface terms

      // Reradiation (surface loss) term
      Galerkin { [ alpha/2 * Dof{PhiIn} , {PhiIn} ] ; 
                 In Sur_Phi ; Integration I1; Jacobian JSur;  }
      // Input (surface source) flux
      Galerkin { [ -Flux[] , {PhiIn} ]; // - sign for incoming flux
                 In Sur_Source_PhiIn; Integration I1; Jacobian JSur;  }
    }
  }

  // Second problem: diffusion out
  { Name DOut ; Type FemEquation; 
    Quantity { 
      { Name PhiIn;   Type Local; NameOfSpace phiIn; }
      { Name PhiOut;  Type Local; NameOfSpace phiOut; }
    }
    Equation {
      // Diffusion term: kappa is combination of mu_s and mu_a
      Galerkin { [ kappa[] * Dof{d PhiOut} , {d PhiOut} ]; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
      // Attenuation (body loss) term
      Galerkin { [ mu_a[] * Dof{PhiOut} , {PhiOut} ] ; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
      // Time dependence
      Galerkin { Dt [ 1/c * Dof{PhiOut} , {PhiOut} ]; 
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
      // Extra term:
      // fluorescence (body source) term
      Galerkin { [ -sigmax[] * {PhiIn} , {PhiOut} ] ; // - sign for source???
                 In Vol_Phi ; Integration I1; Jacobian JVol;  }
 
      // end of volume terms, beginning of surface terms

      // Reradiation (surface loss) term
      Galerkin { [ alpha/2 * Dof{PhiOut} , {PhiOut} ] ; 
                 In Sur_Phi ; Integration I1; Jacobian JSur;  }
      // Input (surface source) flux
      Galerkin { [ -FluxOut[] , {PhiOut} ]; // - sign for incoming flux
                 In Sur_Source_PhiOut; Integration I1; Jacobian JSur;  }
    }
  }

}


Resolution {
  { Name both;
    System {
      { Name SysIn;  NameOfFormulation DIn; }
      { Name SysOut; NameOfFormulation DOut; }
    }
    Operation { 
      InitSolution SysIn ; 
      SaveSolution SysIn ;
      InitSolution SysOut;
      SaveSolution SysOut;
      TimeLoopTheta {
        Time0  t0 ; TimeMax t1 ; DTime dt ; Theta dtTheta ;
        Operation { 
          Generate SysIn ;  Solve SysIn ; 
          Test[SaveFct[]] {SaveSolution SysIn;} 
          Generate SysOut;  Solve SysOut; 
          Test[SaveFct[]] {SaveSolution SysOut;} 
        } 
      } 
//       InitSolution SysOut ; SaveSolution SysOut ;
//       TimeLoopTheta {
//         Time0  t0 ; TimeMax t1 ; DTime dt ; Theta dtTheta ;
//         Operation { 
//           Generate SysOut ; Solve SysOut ; 
//           Test[SaveFct[]] {SaveSolution SysOut;} 
//         } 
//       } 
    }
  }

//   { Name linear_fast;
//     System {
//       { Name SysIn; NameOfFormulation DIn; }
//     }
//     Operation { 
//       InitSolution SysIn ;  SaveSolution SysIn ;
//       GenerateSeparate SysIn ;
//       TimeLoopTheta {
//         Time0  t0 ; TimeMax t1 ; DTime dt ; Theta dtTheta ;
//         Operation { 
//           Update[SysIn,TimeFct[]] ; 
//           Solve SysIn ; 
//           Test[SaveFct[]] {SaveSolution SysIn;} 
//         } 
//       } 
//     }
//   }

}


PostProcessing {
  { Name both; NameOfFormulation DOut;
    Quantity {
      { Name PhiIn ; Value{ Local{ [ {PhiIn } ] ; In Vol_Phi; } } }
      { Name PhiOut; Value{ Local{ [ {PhiOut} ] ; In Vol_Phi; } } }
    }
  }
  
}
